about summary refs log tree commit homepage
path: root/lib
diff options
context:
space:
mode:
authorEric Wong <normalperson@yhbt.net>2010-11-16 16:00:07 -0800
committerEric Wong <normalperson@yhbt.net>2010-11-16 16:00:07 -0800
commit958c1f81a2c570f4027d8fe2dd4f5c40ac7ed430 (patch)
tree768feffdfe36a50aa945a5e0658e937e8b49bace /lib
parent431de671a29b312bd19e615bd4bd99228b0c8b13 (diff)
downloadunicorn-958c1f81a2c570f4027d8fe2dd4f5c40ac7ed430.tar.gz
Rewindable "rack.input" may be disabled via the
"rewindable_input false" directive in the configuration file.
This will violate Rack::Lint for Rack 1.x applications, but
can reduce I/O for applications that do not need it.

There are also internal cleanups and enhancements for future
versions of Rainbows!

Eric Wong (11):
      t0012: fix race condition in reload
      enable HTTP keepalive support for all methods
      http_parser: add HttpParser#next? method
      tee_input: switch to simpler API for parsing trailers
      switch versions to 3.0.0pre
      add stream_input class and build tee_input on it
      configurator: enable "rewindable_input" directive
      http_parser: ensure keepalive is disabled when reset
      *_input: make life easier for subclasses/modules
      tee_input: restore read position after #size
      preread_input: no-op for non-rewindable "rack.input"
Diffstat (limited to 'lib')
-rw-r--r--lib/unicorn/const.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/unicorn/const.rb b/lib/unicorn/const.rb
index cdb5f11..375f72f 100644
--- a/lib/unicorn/const.rb
+++ b/lib/unicorn/const.rb
@@ -7,8 +7,8 @@
 # improve things much compared to constants.
 module Unicorn::Const
 
-  # The current version of Unicorn, currently 3.0.0pre
-  UNICORN_VERSION = "3.0.0pre"
+  # The current version of Unicorn, currently 3.0.0pre1
+  UNICORN_VERSION = "3.0.0pre1"
 
   # default TCP listen host address (0.0.0.0, all interfaces)
   DEFAULT_HOST = "0.0.0.0"